import CardCom from '@/components/Card'
import { RouterLink } from 'vue-router'
import { NButton, NIcon, NGradientText } from 'naive-ui'
import { AddOutline } from '@vicons/ionicons5'
import { getCodesByTypeId } from '@/api/codes'
import { useRequest } from 'vue-hooks-plus'
import { SandpackProvider, SandpackPreview, JustIframeStory } from 'sandpack-vue3'

export default defineComponent({
  props: {
    cardData: {
      type: Object,
      required: true,
    },
  },
  setup(props) {
    const { cardData } = toRefs(props)

    const { data: codeList } = useRequest(() => getCodesByTypeId(cardData.value.id))

    // const getCode = (codeId: string) => {
    //   const { data: codeData } = useRequest(() => getCodeById(codeId))
    //   return codeData
    // }

    return () => (
      <div class="border border-[var(--border-color)] rounded-lg">
        <div class="flex items-center bg-[var(--border-color)] rounded-t-lg px-5 py-2 text-xl">
          {/* <div>{cardData.value.name}</div> */}
          <NGradientText type="success">{cardData.value.name}</NGradientText>
          <RouterLink
            class="ml-auto"
            to={{ name: 'codeEditor', query: { type: cardData.value.name } }}
            tag="a"
            target="_blank"
          >
            <NButton
              type="primary"
              strong
              secondary
              v-slots={{
                icon: () => {
                  return (
                    <NIcon>
                      <AddOutline />
                    </NIcon>
                  )
                },
              }}
            ></NButton>
          </RouterLink>
        </div>
        <div class="p-5 flex flex-wrap gap-5">
          {codeList.value?.map((code, i) => {
            console.log(code)
            return (
              <RouterLink
                class="w-[200px] cursor-pointer transition hover:scale-110 hover:rotate-3 hover:shadow-2xl"
                to={{ name: 'codeEditor', query: { id: code.id, type: cardData.value.name } }}
                tag="a"
                target="_blank"
              >
                {/* {{ code }} */}
                <CardCom
                  data={code}
                  v-slots={{
                    default: () => {
                      return (
                        <SandpackProvider files={code.code} template={code.template_id}>
                          <SandpackPreview
                            showOpenInCodeSandbox={false}
                            showRefreshButton={false}
                          ></SandpackPreview>
                        </SandpackProvider>
                      )
                    },
                  }}
                ></CardCom>
              </RouterLink>
            )
          })}
        </div>
      </div>
    )
  },
})
