import { h } from 'vue'
import { NIcon, NMenu } from 'naive-ui'
import type { MenuOption } from 'naive-ui'

import { BookmarkOutline, CaretDownOutline } from '@vicons/ionicons5'
import IconCesium from '@/components/icons/IconCesium.vue'
import IconVue from '@/components/icons/IconVue.vue'
import IconHtml from '@/components/icons/IconHtml.vue'

import useTypes from '@/hooks/Types'

const renderMenuLabel = (option: MenuOption) => {
  if ('href' in option) {
    return h('a', { href: option.href, target: '_blank' }, option.name as string)
  }
  return option.name as string
}

const iconDict = {
  Cesium: IconCesium,
  Vue: IconVue,
  HTML: IconHtml,
}

const renderMenuIcon = (option: MenuOption) => {
  return h(NIcon, null, { default: () => h(iconDict[option.name] ?? BookmarkOutline) })
}

const expandIcon = () => {
  return h(NIcon, null, { default: () => h(CaretDownOutline) })
}

export default defineComponent({
  setup() {
    const { data: menuOptions } = useTypes()
    const value = ref<string>('')

    watch(value, (newVal) => {
      console.log(newVal)
    })
    return () => (
      <>
        <NMenu
          v-model:value={value.value}
          class="w-h-full"
          // collapsed={collapsed.value}
          key-field="name"
          label-field="name"
          collapsed-width={64}
          collapsed-icon-size={22}
          options={menuOptions.value as MenuOption[]}
          render-label={renderMenuLabel}
          render-icon={renderMenuIcon}
          expand-icon={expandIcon}
        ></NMenu>
      </>
    )
  },
})
